
# q-expansion of newform 3120.2.l.q, downloaded from the LMFDB on 29 April 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 3120
weight = 2
poly_data = [4, 0, 61, 0, 97, 0, 56, 0, 13, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-1, 0, -29, 0, -34, 0, -11, 0, -1, 0], 1], [[0, -16, 97, 93, 110, 110, 34, 34, 3, 3], 4], [[0, 16, 97, -93, 110, -110, 34, -34, 3, -3], 4], [[-12, 0, -257, 0, -266, 0, -80, 0, -7, 0], 2], [[20, -14, 203, 151, 198, 178, 58, 56, 5, 5], 4], [[0, -13, 0, -82, 0, -78, 0, -23, 0, -2], 2], [[0, 14, 0, 54, 0, 44, 0, 12, 0, 1], 1], [[20, 14, 203, -151, 198, -178, 58, -56, 5, -5], 4], [[0, 5, 0, 177, 0, 188, 0, 57, 0, 5], 2]]

hecke_ring_character_values = [[1951, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [2341, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [2081, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [2497, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [2641, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0], [0, 0, 0, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -1], [-1, 0, 0, 0, 1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, 0, 0], [0, 0, 1, -1, 0, 1, 2, 0, -1, -1], [1, 1, 0, 0, 1, -1, 0, 0, -1, 0], [0, 0, -1, 1, 0, -1, 0, 0, 1, 1], [-1, 1, 1, 1, 1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -2, 0, 0, -2, 0], [0, 0, -2, 2, 0, -1, 1, 1, 1, 2], [-1, 2, 1, 1, 3, 1, 0, 0, 1, 0], [0, 0, 1, -1, 0, 1, 2, 0, -1, -4], [0, 0, -1, 1, 0, -2, -4, -2, 2, 2], [0, 0, 2, -2, 0, 3, 1, 1, -3, -4], [4, 2, -1, -1, 2, -2, 0, 0, -2, 0], [-3, 0, -2, -2, -3, -1, 0, 0, -1, 0], [0, 0, -2, 2, 0, -2, -4, 0, 2, 4], [-1, -2, -3, -3, -3, -1, 0, 0, -1, 0], [0, 0, -2, 2, 0, 1, -3, 1, -1, 1], [3, -4, -2, -2, -3, 1, 0, 0, 1, 0], [0, 0, -1, 1, 0, 0, 0, 2, 0, -2], [-1, -2, -1, -1, -1, 1, 0, 0, 1, 0], [0, 0, 0, 0, 0, 2, 4, 2, -2, -3], [1, -3, -3, -3, -1, 2, 0, 0, 2, 0], [0, 0, 0, 0, 0, -4, -4, -2, 4, 2], [0, 0, -2, 2, 0, 1, -3, 3, -1, 0], [5, -3, -4, -4, -1, 1, 0, 0, 1, 0], [0, 0, -1, 1, 0, -2, -5, -1, 2, 1], [0, 0, 1, -1, 0, -1, 0, 4, 1, 0], [-3, -1, -3, -3, 1, 4, 0, 0, 4, 0], [0, 0, 3, -3, 0, 0, 0, 0, 0, 2], [3, 0, 1, 1, -1, 0, 0, 0, 0, 0], [3, 0, 0, 0, -1, 2, 0, 0, 2, 0], [0, 2, 2, 2, 0, -4, 0, 0, -4, 0], [0, 0, -1, 1, 0, 1, 12, 0, -1, -2], [0, 0, -6, 6, 0, -1, -1, 1, 1, 2], [0, 0, 1, -1, 0, 4, -2, 0, -4, -4], [0, 0, -2, 2, 0, -2, -6, 4, 2, 4], [11, -5, -3, -3, -1, 4, 0, 0, 4, 0], [-9, 4, 3, 3, 5, 0, 0, 0, 0, 0], [0, 6, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 2, 0, -3], [0, 0, -1, 1, 0, 4, 8, 0, -4, -2], [4, 2, -1, -1, 6, -1, 0, 0, -1, 0], [0, -2, -3, -3, -2, 1, 0, 0, 1, 0], [0, 0, 0, 0, 0, 1, -1, 1, -1, 1], [0, 0, -1, 1, 0, 0, -10, 0, 0, -2], [7, 5, 0, 0, 1, -1, 0, 0, -1, 0], [0, 0, 5, -5, 0, 1, -4, -2, -1, -3], [11, -4, -3, -3, -3, 1, 0, 0, 1, 0], [-2, -6, 0, 0, 0, -2, 0, 0, -2, 0], [-7, 5, 1, 1, 1, 0, 0, 0, 0, 0], [0, 0, 3, -3, 0, 0, 9, 1, 0, -5], [0, 0, -3, 3, 0, 2, 1, -5, -2, 1], [7, 3, -1, -1, 1, -6, 0, 0, -6, 0], [0, 2, 4, 4, 0, 0, 0, 0, 0, 0], [0, 0, -1, 1, 0, -5, 10, -2, 5, 2], [6, 0, 2, 2, -6, -1, 0, 0, -1, 0], [0, 0, 6, -6, 0, 2, 4, 0, -2, -6], [0, 0, 3, -3, 0, 4, 2, 2, -4, -6], [0, 0, -2, 2, 0, 1, -13, -3, -1, 0], [-10, 6, 0, 0, -2, 0, 0, 0, 0, 0], [0, 0, 3, -3, 0, -3, -14, 0, 3, 4], [0, 0, -3, 3, 0, -2, 0, 0, 2, 0], [3, 3, 4, 4, 7, 3, 0, 0, 3, 0], [0, 0, 3, -3, 0, 1, 14, 4, -1, -4], [0, 0, 0, 0, 0, 1, -15, -5, -1, 0], [7, -3, -4, -4, 1, -3, 0, 0, -3, 0], [0, 0, -1, 1, 0, 2, 0, 0, -2, -2], [0, 4, 0, 0, -2, 3, 0, 0, 3, 0], [0, 0, -2, 2, 0, -6, 4, -2, 6, 2], [0, 0, -4, 4, 0, -4, -2, 0, 4, -4], [-13, 3, 2, 2, 3, 3, 0, 0, 3, 0], [0, 0, 1, -1, 0, 2, 6, 4, -2, 4], [13, -1, -1, -1, -5, 2, 0, 0, 2, 0], [0, 0, 4, -4, 0, -1, 7, 3, 1, -4], [10, 8, 2, 2, 2, -5, 0, 0, -5, 0], [16, 0, -2, -2, 2, 2, 0, 0, 2, 0], [11, -3, -3, -3, -5, 2, 0, 0, 2, 0], [-13, 1, -6, -6, -3, -3, 0, 0, -3, 0], [10, -2, 2, 2, 0, 3, 0, 0, 3, 0], [0, 0, 5, -5, 0, -3, -8, -2, 3, 4], [1, 6, 9, 9, 1, -6, 0, 0, -6, 0], [0, 0, 4, -4, 0, 5, 7, -3, -5, -8], [1, 2, 7, 7, 1, -3, 0, 0, -3, 0], [0, 0, -6, 6, 0, -8, 4, -2, 8, 9], [-11, 2, 0, 0, -3, -2, 0, 0, -2, 0], [0, 0, 8, -8, 0, -2, 6, 2, 2, -1], [0, 0, 0, 0, 0, -1, -15, 3, 1, 4], [1, 0, 7, 7, 3, 1, 0, 0, 1, 0], [0, 0, 0, 0, 0, 4, 10, 2, -4, -9], [-17, -1, 5, 5, -1, -2, 0, 0, -2, 0], [-3, -1, 2, 2, 1, -1, 0, 0, -1, 0], [0, 0, -5, 5, 0, 0, 5, -1, 0, 9], [9, 2, -4, -4, 1, 4, 0, 0, 4, 0], [10, -4, -2, -2, -4, 8, 0, 0, 8, 0], [0, 0, -5, 5, 0, -5, -6, 0, 5, 6], [-19, -7, 0, 0, -5, 1, 0, 0, 1, 0], [0, 0, 1, -1, 0, 7, -8, 10, -7, -10], [0, 0, 1, -1, 0, 2, -8, -4, -2, -8], [0, 0, -4, 4, 0, -9, 3, 1, 9, 4], [0, 4, 2, 2, 2, -6, 0, 0, -6, 0], [-5, 6, 8, 8, 1, -5, 0, 0, -5, 0], [0, 0, 2, -2, 0, 4, 2, 4, -4, -9], [0, 0, 5, -5, 0, 2, 0, 2, -2, -6], [0, 0, 1, -1, 0, 0, -4, 8, 0, 0], [-2, 12, 4, 4, 6, 0, 0, 0, 0, 0], [1, -2, 2, 2, -7, 3, 0, 0, 3, 0], [0, 0, 2, -2, 0, -4, -6, 4, 4, -6], [0, 0, 4, -4, 0, 5, -15, 1, -5, -6], [0, 0, 1, -1, 0, 6, -18, 2, -6, 2], [1, -5, 0, 0, -3, -3, 0, 0, -3, 0], [10, -2, -6, -6, -2, -6, 0, 0, -6, 0], [6, 2, 4, 4, 8, 4, 0, 0, 4, 0], [0, 0, 0, 0, 0, 7, 19, 1, -7, -2], [0, 0, 11, -11, 0, 1, 0, -4, -1, -3], [0, 0, 6, -6, 0, 0, 20, 6, 0, -2], [-1, 9, 1, 1, 3, -8, 0, 0, -8, 0], [-1, -7, -8, -8, 5, 5, 0, 0, 5, 0], [0, 0, 2, -2, 0, 4, 14, 10, -4, -8], [0, 0, 2, -2, 0, 5, -1, 3, -5, 4], [0, 0, 1, -1, 0, -4, 8, -2, 4, -2], [21, -1, 0, 0, -3, 1, 0, 0, 1, 0], [3, 5, 1, 1, -7, -2, 0, 0, -2, 0], [17, -3, 2, 2, 3, -1, 0, 0, -1, 0], [6, -4, 2, 2, -6, -6, 0, 0, -6, 0], [0, 0, -3, 3, 0, -5, 4, -8, 5, 6], [0, 0, -10, 10, 0, 1, 5, -3, -1, 8], [11, -5, -2, -2, -5, 1, 0, 0, 1, 0], [0, 0, 3, -3, 0, 4, 0, -2, -4, -8], [3, -6, 7, 7, 3, -2, 0, 0, -2, 0], [0, 0, 8, -8, 0, 0, -6, 0, 0, 0], [2, -4, 4, 4, -2, 5, 0, 0, 5, 0], [14, -12, -8, -8, -8, 4, 0, 0, 4, 0], [0, 0, -3, 3, 0, 6, 8, -4, -6, 2], [0, 0, -8, 8, 0, -4, -4, -4, 4, 4], [0, 0, 4, -4, 0, 3, 7, -5, -3, -10], [-10, 2, 10, 10, -4, 0, 0, 0, 0, 0], [15, 11, 0, 0, 3, 1, 0, 0, 1, 0], [-5, -16, -10, -10, -1, 12, 0, 0, 12, 0], [0, 0, 0, 0, 0, 0, -12, 10, 0, -6], [0, 0, 1, -1, 0, 8, -16, 6, -8, -2], [18, 6, 1, 1, 2, 3, 0, 0, 3, 0], [11, -8, -9, -9, -3, -1, 0, 0, -1, 0], [0, 0, 4, -4, 0, -1, -1, -9, 1, 0], [0, 0, -1, 1, 0, -3, -2, 4, 3, 5], [-3, 0, 6, 6, 3, 3, 0, 0, 3, 0], [0, 0, 5, -5, 0, 2, 4, -6, -2, -4], [0, 0, -4, 4, 0, -4, -20, -10, 4, 6], [16, -6, -6, -6, 2, -2, 0, 0, -2, 0], [0, 0, -2, 2, 0, 4, -2, -2, -4, 0], [0, 0, 5, -5, 0, 5, 14, 2, -5, -1], [0, 0, 4, -4, 0, 0, 12, 0, 0, -2], [-14, 8, 2, 2, 2, 0, 0, 0, 0, 0], [-1, -4, -4, -4, 1, -5, 0, 0, -5, 0], [15, -6, -1, -1, 3, 11, 0, 0, 11, 0], [0, 0, 9, -9, 0, 7, 18, 4, -7, 2], [-23, 4, 0, 0, -3, -2, 0, 0, -2, 0], [0, 0, 11, -11, 0, 0, -4, -2, 0, -10], [0, 0, 3, -3, 0, 9, 10, 0, -9, 1], [0, 0, -6, 6, 0, -1, 31, 1, 1, 5], [9, -7, -1, -1, 1, 4, 0, 0, 4, 0], [0, 0, 1, -1, 0, 8, -14, 10, -8, -8], [0, 0, 3, -3, 0, 0, 12, 2, 0, 8], [-9, 2, -7, -7, -1, -4, 0, 0, -4, 0], [0, 0, -3, 3, 0, 9, -6, 6, -9, -6], [0, -2, 0, 0, -6, 8, 0, 0, 8, 0], [0, 0, -6, 6, 0, -1, -9, 3, 1, 2], [-10, 8, 15, 15, 4, -4, 0, 0, -4, 0], [-29, -5, 4, 4, 1, -3, 0, 0, -3, 0], [4, -12, -10, -10, 4, 4, 0, 0, 4, 0], [0, 0, 4, -4, 0, 12, 22, 4, -12, -15], [21, 10, 7, 7, 5, -4, 0, 0, -4, 0], [8, -6, -8, -8, 6, -2, 0, 0, -2, 0], [-7, -9, -4, -4, -3, 9, 0, 0, 9, 0], [-7, -4, -4, -4, 13, -2, 0, 0, -2, 0], [0, 0, 2, -2, 0, 2, -4, 2, -2, -8], [-4, -16, -7, -7, 0, 13, 0, 0, 13, 0], [0, 0, 10, -10, 0, -2, 4, -12, 2, 3], [3, -5, -3, -3, -9, 4, 0, 0, 4, 0], [0, 0, 0, 0, 0, 4, -6, 4, -4, 4], [0, 0, -5, 5, 0, 2, -12, 0, -2, 0], [0, 0, 13, -13, 0, 4, 4, -2, -4, 0], [17, 1, -7, -7, -1, -4, 0, 0, -4, 0], [0, 0, 9, -9, 0, 3, 0, -4, -3, -2], [0, 0, 2, -2, 0, 5, 9, -1, -5, -6], [-4, 2, -8, -8, -6, 4, 0, 0, 4, 0], [-1, 0, 1, 1, -3, -9, 0, 0, -9, 0], [0, 0, 2, -2, 0, 2, 16, 0, -2, 4], [0, 0, -9, 9, 0, -6, -8, 6, 6, 18], [-7, 14, 1, 1, 5, 6, 0, 0, 6, 0], [19, -8, -6, -6, -1, 2, 0, 0, 2, 0], [0, 0, -8, 8, 0, -8, 4, -8, 8, 12], [0, 0, -5, 5, 0, -1, 0, 6, 1, -9], [-24, 0, -4, -4, 6, 6, 0, 0, 6, 0], [0, 0, 6, -6, 0, -4, -4, 6, 4, -8], [0, 0, -9, 9, 0, -8, -2, -2, 8, 4], [0, 0, -7, 7, 0, 5, 10, 2, -5, -9], [-8, 12, 5, 5, 0, -4, 0, 0, -4, 0], [21, 22, 9, 9, 5, -14, 0, 0, -14, 0], [0, 0, -6, 6, 0, 5, 1, 9, -5, 4], [-15, 12, 11, 11, 7, 6, 0, 0, 6, 0], [-5, 8, 6, 6, -7, -4, 0, 0, -4, 0], [0, 0, 0, 0, 0, 3, -41, 7, -3, -6], [-2, -12, -6, -6, -2, 2, 0, 0, 2, 0], [0, 0, 8, -8, 0, 8, 18, 6, -8, -14], [-5, 18, 3, 3, 3, -9, 0, 0, -9, 0], [-1, 8, 8, 8, 1, -1, 0, 0, -1, 0], [0, 0, -5, 5, 0, -15, -2, -4, 15, 8], [-21, 11, 3, 3, 5, 4, 0, 0, 4, 0], [0, 0, -11, 11, 0, -7, -30, -6, 7, 2], [0, 0, -5, 5, 0, -8, -16, 2, 8, -6], [26, -2, -4, -4, -12, 7, 0, 0, 7, 0], [-2, 14, 10, 10, 16, -2, 0, 0, -2, 0], [0, 0, 7, -7, 0, 3, 10, -6, -3, 6], [-22, 4, 0, 0, 4, -12, 0, 0, -12, 0], [0, 0, -3, 3, 0, 6, -2, 12, -6, 4], [0, 0, -5, 5, 0, -12, 22, 6, 12, 4], [5, 8, -1, -1, 3, -6, 0, 0, -6, 0], [-20, 8, 8, 8, 8, 0, 0, 0, 0, 0], [2, -12, -6, -6, -14, -9, 0, 0, -9, 0], [0, 0, -4, 4, 0, 3, -7, -9, -3, -1], [0, 0, -10, 10, 0, -5, -1, 5, 5, 6], [13, -8, -1, -1, -9, -10, 0, 0, -10, 0], [0, 0, 5, -5, 0, -9, 8, -2, 9, -7], [10, 0, 4, 4, 10, 0, 0, 0, 0, 0], [0, 0, -7, 7, 0, -5, 16, 4, 5, 6], [15, -16, -12, -12, -3, 14, 0, 0, 14, 0], [0, 0, -3, 3, 0, 3, 20, -8, -3, 10], [17, 2, -11, -11, 5, -2, 0, 0, -2, 0], [32, -18, -6, -6, 4, 10, 0, 0, 10, 0], [52, -2, -4, -4, -2, -2, 0, 0, -2, 0], [0, 0, -1, 1, 0, 1, 8, -6, -1, 12], [0, 0, 3, -3, 0, 2, 40, 2, -2, -4], [6, 12, -2, -2, -4, -8, 0, 0, -8, 0], [0, 0, -9, 9, 0, -4, 0, 4, 4, 12], [17, 3, -5, -5, 5, -8, 0, 0, -8, 0], [-22, -2, -4, -4, 6, 10, 0, 0, 10, 0], [0, 0, -5, 5, 0, -10, -34, -12, 10, 10], [3, -16, -8, -8, -11, -1, 0, 0, -1, 0], [0, 0, -5, 5, 0, -7, -4, 0, 7, -2], [9, -17, -2, -2, 7, 5, 0, 0, 5, 0], [0, 0, -1, 1, 0, 4, 20, 0, -4, 4], [2, -10, -12, -12, -14, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 5, 25, -1, -5, -13], [-43, 6, 8, 8, 11, -8, 0, 0, -8, 0], [-3, -7, 0, 0, -3, 15, 0, 0, 15, 0], [0, 0, 3, -3, 0, 0, 13, 3, 0, -7], [0, 0, -10, 10, 0, 8, -4, 14, -8, -10], [2, 4, 0, 0, -18, -3, 0, 0, -3, 0], [0, 0, -3, 3, 0, 10, -18, 4, -10, -2], [7, -4, -8, -8, -1, -9, 0, 0, -9, 0], [0, 0, 0, 0, 0, 9, 15, -9, -9, -8], [-3, 22, 4, 4, 3, -12, 0, 0, -12, 0], [-46, 6, 7, 7, 2, 1, 0, 0, 1, 0], [0, 0, 0, 0, 0, 11, 1, 3, -11, 2], [0, 0, -2, 2, 0, -6, -16, 2, 6, -2], [0, 0, 0, 0, 0, 12, -4, 14, -12, -15], [0, 0, 9, -9, 0, 9, 2, 10, -9, -18], [0, 0, -18, 18, 0, -9, 9, -5, 9, 18], [1, -3, -14, -14, -5, 7, 0, 0, 7, 0], [0, 0, 7, -7, 0, 11, 14, 10, -11, -10], [0, 0, -5, 5, 0, -2, -26, -2, 2, -4], [-7, -10, -6, -6, -1, 3, 0, 0, 3, 0], [5, 14, 8, 8, -3, -6, 0, 0, -6, 0], [-3, 10, -5, -5, 1, -9, 0, 0, -9, 0], [0, 0, 4, -4, 0, 9, -7, -5, -9, -2], [0, 0, -2, 2, 0, -8, -4, -10, 8, 22], [-12, -4, -5, -5, -8, 7, 0, 0, 7, 0], [0, 0, -4, 4, 0, 1, 33, -5, -1, -4], [0, 0, -14, 14, 0, -6, 6, -8, 6, 21], [-4, 4, 4, 4, -4, 4, 0, 0, 4, 0], [0, 0, -7, 7, 0, -3, -32, 2, 3, 6], [0, 0, -2, 2, 0, 0, -2, -2, 0, 9], [0, 0, 9, -9, 0, -2, 12, -18, 2, -2], [-3, -5, 0, 0, 7, 11, 0, 0, 11, 0], [-24, 12, 8, 8, 14, -14, 0, 0, -14, 0], [9, 1, -1, -1, -3, -18, 0, 0, -18, 0], [0, 0, -3, 3, 0, -3, 2, -10, 3, 3], [-10, 4, 0, 0, 6, -10, 0, 0, -10, 0], [0, 0, 1, -1, 0, 6, -9, 5, -6, -17], [-47, 11, 8, 8, 3, 7, 0, 0, 7, 0], [0, 0, 8, -8, 0, 6, -2, 10, -6, -6], [-14, -14, -12, -12, 6, 18, 0, 0, 18, 0], [0, 0, 5, -5, 0, 7, -42, -4, -7, 0], [0, 0, 11, -11, 0, 0, -8, -4, 0, -2], [-26, -8, 8, 8, 2, -4, 0, 0, -4, 0], [-12, 12, -2, -2, 2, 10, 0, 0, 10, 0], [19, -9, -3, -3, -7, -10, 0, 0, -10, 0], [0, 0, 8, -8, 0, 6, -22, -2, -6, -14], [0, 0, 3, -3, 0, 6, 20, 8, -6, -16], [2, 0, 1, 1, -12, -12, 0, 0, -12, 0], [0, 0, 5, -5, 0, 5, 38, 6, -5, -2], [-23, 19, 9, 9, 11, 4, 0, 0, 4, 0], [16, 4, 6, 6, -16, -6, 0, 0, -6, 0], [0, 0, 6, -6, 0, 5, -13, -5, -5, -20], [-27, -11, -1, -1, -3, 8, 0, 0, 8, 0], [0, 0, -6, 6, 0, 9, 15, 9, -9, -8], [0, 0, -14, 14, 0, 2, 4, 0, -2, 2], [0, 0, 13, -13, 0, -4, -10, 10, 4, -14], [15, -14, -7, -7, -9, -4, 0, 0, -4, 0]]
